@@ -75,7 +75,7 @@ class cmd_update(Command):
         config.build_targets = ['checkout']
         config.nonetwork = False
 
-        build = jhbuild.frontends.get_buildscript(config, module_list)
+        build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
         return build.build()
 
 register_command(cmd_update)
@@ -109,7 +109,7 @@ class cmd_updateone(Command):
         config.build_targets = ['checkout']
         config.nonetwork = False
 
-        build = jhbuild.frontends.get_buildscript(config, module_list)
+        build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
         return build.build()
 
 register_command(cmd_updateone)
@@ -145,7 +145,7 @@ class cmd_cleanone(Command):
                     _('clean command called while makeclean is set to False, skipped.'))
             return 0
 
-        build = jhbuild.frontends.get_buildscript(config, module_list)
+        build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
         return build.build(phases=['clean'])
 
 register_command(cmd_cleanone)
@@ -160,7 +160,7 @@ def check_bootstrap_updateness(config):
     except:
         # failed to get bootstrap moduleset, silently ignore.
         return
-    packagedb = jhbuild.frontends.get_buildscript(config, []).packagedb
+    packagedb = module_set.packagedb
 
     max_install_date = max([
             packagedb.installdate(module.name)
@@ -173,9 +173,10 @@ def check_bootstrap_updateness(config):
 
     updated_modules = []
     for module in module_set.modules.values():
-        if not packagedb.entries.has_key(module.name):
+        pkg = packagedb.entries.get(module.name)
+        if pkg is None:
             continue
-        p_version = packagedb.entries.get(module.name)[0]
+        p_version = pkg.version
         if p_version != module.get_revision():
             updated_modules.append(module.name)
 
@@ -288,7 +289,7 @@ class cmd_build(Command):
                     _('requested module is in the ignore list, nothing to do.'))
             return 0
 
-        build = jhbuild.frontends.get_buildscript(config, module_list)
+        build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
         return build.build()
 
 register_command(cmd_build)
@@ -344,15 +345,25 @@ class cmd_buildone(Command):
             check_bootstrap_updateness(config)
 
         module_set = jhbuild.moduleset.load(config)
-        try:
-            module_list = [module_set.get_module(modname, ignore_case = True) for modname in args]
-        except KeyError, e:
-            raise FatalError(_("A module called '%s' could not be found.") % e)
+        module_list = []
+        for modname in args:
+            try:
+                module = module_set.get_module(modname, ignore_case=True)
+            except KeyError, e:
+                default_repo = jhbuild.moduleset.get_default_repo()
+                if not default_repo:
+                    continue
+                from jhbuild.modtypes.autotools import AutogenModule
+                module = AutogenModule(modname, default_repo.branch(modname))
+                module.config = config
+                logging.info(_('module "%s" does not exist, created automatically using repository "%s"') % \
+                                (modname, default_repo.name))
+            module_list.append(module)
 
         if not module_list:
             self.parser.error(_('This command requires a module parameter.'))
 
-        build = jhbuild.frontends.get_buildscript(config, module_list)
+        build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
         return build.build()
 
 register_command(cmd_buildone)
@@ -396,7 +407,7 @@ class cmd_run(Command):
             except KeyError, e:
                 raise FatalError(_("A module called '%s' could not be found.") % e)
 
-            build = jhbuild.frontends.get_buildscript(config, module_list)
+            build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
             builddir = module_list[0].get_builddir(build)
             try:
                 build.execute(args, cwd=builddir)
@@ -413,7 +424,7 @@ class cmd_run(Command):
             except KeyError, e:
                 raise FatalError(_("A module called '%s' could not be found.") % e)
 
-            build = jhbuild.frontends.get_buildscript(config, module_list)
+            build = jhbuild.frontends.get_buildscript(config, module_list, module_set=module_set)
             checkoutdir = module_list[0].get_srcdir(build)
             try:
                 build.execute(args, cwd=checkoutdir)
@@ -483,6 +494,11 @@ class cmd_list(Command):
     def run(self, config, options, args, help=None):
         config.set_from_cmdline_options(options)
         module_set = jhbuild.moduleset.load(config)
+        if options.startat and options.list_all_modules:
+            raise UsageError(_('Conflicting options specified '
+                               '(\'%s\' and \'%s\')') % \
+                               ('--start-at', '--all-modules'))
+
         if options.list_all_modules:
             module_list = module_set.modules.values()
         else:
