@@ -26,7 +26,7 @@ import re
 
 from jhbuild.errors import FatalError, BuildStateError, CommandError
 from jhbuild.modtypes import \
-     Package, DownloadableModule, get_dependencies, get_branch, register_module_type
+     Package, DownloadableModule, register_module_type
 from jhbuild.commands.sanitycheck import inpath
 
 __all__ = [ 'WafModule' ]
@@ -44,11 +44,10 @@ class WafModule(Package, DownloadableModule):
     PHASE_DIST           = 'dist'
     PHASE_INSTALL        = 'install'
 
-    def __init__(self, name, branch, dependencies=[], after=[], suggests=[],
-                 waf_cmd='./waf'):
-        Package.__init__(self, name, dependencies, after, suggests)
-        self.branch = branch
+    def __init__(self, name, branch=None, waf_cmd='./waf'):
+        Package.__init__(self, name, branch=branch)
         self.waf_cmd = waf_cmd
+        self.supports_install_destdir = True
 
     def get_srcdir(self, buildscript):
         return self.branch.srcdir
@@ -56,9 +55,6 @@ class WafModule(Package, DownloadableModule):
     def get_builddir(self, buildscript):
         return self.get_srcdir(buildscript)
 
-    def get_revision(self):
-        return self.branch.tree_id()
-
     def skip_configure(self, buildscript, last_phase):
         # don't skip this stage if we got here from one of the
         # following phases:
@@ -130,16 +126,10 @@ class WafModule(Package, DownloadableModule):
 
     def do_install(self, buildscript):
         buildscript.set_action(_('Installing'), self)
-        cmd = [self.waf_cmd, 'install']
+        destdir = self.prepare_installroot(buildscript)
+        cmd = [self.waf_cmd, 'install', '--destdir', destdir]
         buildscript.execute(cmd, cwd=self.get_builddir(buildscript))
-        buildscript.packagedb.add(self.name, self.get_revision() or '')
-    do_install.depends = [PHASE_BUILD]
-
-    def do_uninstall(self, buildscript):
-        buildscript.set_action(_('Uninstalling'), self)
-        cmd = [self.waf_cmd, 'uninstall']
-        buildscript.execute(cmd, cwd=self.get_builddir(buildscript))
-        buildscript.packagedb.remove(self.name)
+        self.process_install(buildscript, self.get_revision())
     do_install.depends = [PHASE_BUILD]
 
     def xml_tag_and_attrs(self):
@@ -148,16 +138,11 @@ class WafModule(Package, DownloadableModule):
 
 
 def parse_waf(node, config, uri, repositories, default_repo):
-    module_id = node.getAttribute('id')
-    waf_cmd = './waf'
+    instance = WafModule.parse_from_xml(node, config, uri, repositories, default_repo)
+
     if node.hasAttribute('waf-command'):
-        waf_cmd = node.getAttribute('waf-command')
+        instance.waf_cmd = node.getAttribute('waf-command')
 
-    # override revision tag if requested.
-    dependencies, after, suggests = get_dependencies(node)
-    branch = get_branch(node, repositories, default_repo, config)
-
-    return WafModule(module_id, branch, dependencies=dependencies, after=after,
-            suggests=suggests, waf_cmd=waf_cmd)
+    return instance
 
 register_module_type('waf', parse_waf)
